@@ -18,8 +18,8 @@ import fnmatch
 import logging
 import os
 import sys
+import textwrap
 
-import six
 
 import bandit
 from bandit.core import config as b_config
@@ -98,7 +98,7 @@ def _log_option_source(arg_val, ini_val, option_name):
         LOG.info("Using command line arg for %s", option_name)
         return arg_val
     elif ini_val:
-        LOG.info("Using .bandit arg for %s", option_name)
+        LOG.info("Using ini file for %s", option_name)
         return ini_val
     else:
         return None
@@ -151,7 +151,7 @@ def main():
         formatter_class=argparse.RawDescriptionHelpFormatter
     )
     parser.add_argument(
-        'targets', metavar='targets', type=str, nargs='+',
+        'targets', metavar='targets', type=str, nargs='*',
         help='source file(s) or directory(s) to be tested'
     )
     parser.add_argument(
@@ -206,6 +206,13 @@ def main():
         default=output_format, help='specify output format',
         choices=sorted(extension_mgr.formatter_names)
     )
+    parser.add_argument(
+        '--msg-template', action='store',
+        default=None, help='specify output message template'
+                           ' (only usable with --format custom),'
+                           ' see CUSTOM FORMAT section'
+                           ' for list of available values',
+    )
     parser.add_argument(
         '-o', '--output', dest='output_file', action='store', nargs='?',
         type=argparse.FileType('w'), default=sys.stdout,
@@ -238,27 +245,60 @@ def main():
         '--ini', dest='ini_path', action='store', default=None,
         help='path to a .bandit file that supplies command line arguments'
     )
+    python_ver = sys.version.replace('\n', '')
     parser.add_argument(
         '--version', action='version',
-        version='%(prog)s {version}'.format(version=bandit.__version__)
+        version='%(prog)s {version}\n  python version = {python}'.format(
+            version=bandit.__version__, python=python_ver)
     )
+
     parser.set_defaults(debug=False)
     parser.set_defaults(verbose=False)
     parser.set_defaults(ignore_nosec=False)
 
     plugin_info = ["%s\t%s" % (a[0], a[1].name) for a in
-                   six.iteritems(extension_mgr.plugins_by_id)]
+                   extension_mgr.plugins_by_id.items()]
     blacklist_info = []
-    for a in six.iteritems(extension_mgr.blacklist):
+    for a in extension_mgr.blacklist.items():
         for b in a[1]:
             blacklist_info.append('%s\t%s' % (b['id'], b['name']))
 
     plugin_list = '\n\t'.join(sorted(set(plugin_info + blacklist_info)))
-    parser.epilog = ('The following tests were discovered and'
-                     ' loaded:\n\t{0}\n'.format(plugin_list))
+    dedent_text = textwrap.dedent('''
+    CUSTOM FORMATTING
+    -----------------
+
+    Available tags:
+
+        {abspath}, {relpath}, {line},  {test_id},
+        {severity}, {msg}, {confidence}, {range}
+
+    Example usage:
+
+        Default template:
+        bandit -r examples/ --format custom --msg-template \\
+        "{abspath}:{line}: {test_id}[bandit]: {severity}: {msg}"
+
+        Provides same output as:
+        bandit -r examples/ --format custom
+
+        Tags can also be formatted in python string.format() style:
+        bandit -r examples/ --format custom --msg-template \\
+        "{relpath:20.20s}: {line:03}: {test_id:^8}: DEFECT: {msg:>20}"
+
+        See python documentation for more information about formatting style:
+        https://docs.python.org/3.4/library/string.html
+
+    The following tests were discovered and loaded:
+    -----------------------------------------------
+    ''')
+    parser.epilog = dedent_text + "\t{0}".format(plugin_list)
 
     # setup work - parse arguments, and initialize BanditManager
     args = parser.parse_args()
+    # Check if `--msg-template` is not present without custom formatter
+    if args.output_format != 'custom' and args.msg_template is not None:
+        parser.error("--msg-template can only be used with --format=custom")
 
     try:
         b_conf = b_config.BanditConfig(config_file=args.config_file)
@@ -279,8 +319,16 @@ def main():
 
         args.tests = _log_option_source(args.tests, ini_options.get('tests'),
                                         'selected tests')
+        ini_targets = ini_options.get('targets')
+        if ini_targets:
+            ini_targets = ini_targets.split(',')
+        args.targets = _log_option_source(args.targets, ini_targets,
+                                          'selected targets')
         # TODO(tmcpeak): any other useful options to pass from .bandit?
 
+    if not args.targets:
+        LOG.error("No targets found in CLI or ini files, exiting.")
+        sys.exit(2)
     # if the log format string was set in the options, reinitialize
     if b_conf.get_option('log_format'):
         log_format = b_conf.get_option('log_format')
@@ -342,7 +390,8 @@ def main():
                          sev_level,
                          conf_level,
                          args.output_file,
-                         args.output_format)
+                         args.output_format,
+                         args.msg_template)
 
     # return an exit code of 1 if there are results, 0 otherwise
     if b_mgr.results_count(sev_filter=sev_level, conf_filter=conf_level) > 0:
